#!/bin/bash

# Usage
# DEB="https://secostorage.blob.core.windows.net/seco-ne-public/ARM-COM/Ubuntu/Releases/Ubuntu-jammy-2.0-5.15.0-1029-mtk/genio700/packages/install_packages.sh"
# curl -sSL "$DEB" | bash -s "$(dirname "$DEB")" --initial-config

# Function to download predefined files
download_predefined_files() {
    local temp_dir="$1"
    wget -q --show-progress -P "$temp_dir" "${folder_url}/@LINUX_BUILDINFO@"
    wget -q --show-progress -P "$temp_dir" "${folder_url}/@LINUX_HEADERS@"
    wget -q --show-progress -P "$temp_dir" "${folder_url}/@LINUX_IMAGE@"
    wget -q --show-progress -P "$temp_dir" "${folder_url}/@LINUX_MODULES@"
    wget -q --show-progress -P "$temp_dir" "${folder_url}/@LINUX_MTK_HEADERS@"
}

# Check if the URL argument is provided
if [ $# -ne 1 ] && [ $# -ne 2 ]; then
    echo "Usage: $0 <URL to folder containing .deb files>"
    exit 1
fi

# Check if the --initial-config flag is provided
if [[ "$*" == *"--initial-config"* ]]; then
    # Add your code here that should only be executed if --initial-config flag is provided
    echo "Performing initial configuration..."

    echo "Removing mtk kernel packages..."
    sudo apt remove -y linux-headers-mtk
    sudo apt remove -y linux-image-mtk

    echo "Installing chromium instead of firefox..."
    sudo snap remove firefox
    sudo snap install chromium
fi

# URL to the folder containing .deb files
folder_url="$1"

# Temporary directory to download files
temp_dir=$(mktemp -d)

echo "Downloading deb files"
download_predefined_files "$temp_dir"

echo "Installing deb files"
sudo dpkg -i "$temp_dir"/*.deb

echo "Cleaning up"
rm -rf "$temp_dir"

exit 0